@@ -72,4 +72,16 @@
     --- 优化 标题栏 和 状态栏 的代码
     --- 优化获取文字大小函数 textSize() 对丢失像素进行补偿
     --- 优化标题栏 在PyQt6,PySide6,标题高度计算不精准的Bug
+2023.1.8 1.1.9.4版本
+    --- 感谢! PyQt5学习爱好群-(讨厌自己)修复 PyQt6 版本下 无边框类(Borderless)移动BUG
+    --- 增加 内置-样式设计器,主要是为了配合皮肤包
+'''
+
+# ===============================================
+
+'''
+记录已知BUG,但是还未修复
+PyQt6 版本下 无边框类(Borderless)移动有BuG
+轮播组件(SlideShow) 后期将重写
+
 '''
\ No newline at end of file
